/*
 * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
 *
 * gtranslator is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or   
 *    (at your option) any later version.
 *    
 * gtranslator is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GTR_DEFINES
#define GTR_DEFINES 1

#define BUILD_STRING	"1.1.6 -- 2005-02-06 12:56:02"
#define BUILD_VERSIONS	"2.6.1 / 2.6.1 / 2.9.1 / 2.6.17"
#define SCHEMESDIR	"/usr/local/share/gtranslator/colorschemes"
#define SCRIPTSDIR	"/usr/local/share/gtranslator/scripts"
#define WINDOW_ICON	"/usr/local/share/pixmaps/gtranslator.png"

#endif
